@@ -207,8 +207,8 @@ class findpeaks():
             * labx    : The label of the peak area
             * rank    : The ranking number of the best performing peaks (1 is best)
             * score   : persistence score
-            * valley  : Wether the point is marked as valley
-            * peak    : Wether the point is marked as peak
+            * valley  : Whether the point is marked as valley
+            * peak    : Whether the point is marked as peak
 
         Examples
         --------
@@ -414,8 +414,11 @@ class findpeaks():
             * Xproc   : The pre-processed data
             * Xdetect : The detected peaks with the persistence scores (same shape as the input data)
             * XRanked : The detected peaks but based on the strenght (same shape as the input data)
-            * peak    : Coordinates for the detected peaks
-            * valley  : Coordinates for the detected valleys
+            * persistence : pd.DataFrame()
+                * x, y    : coordinates
+                * birth   : Birth level
+                * death   : Death level
+                * score   : persistence scores
 
         Examples
         --------
@@ -476,8 +479,8 @@ class findpeaks():
             results['Xdetect'] = result['Xdetect']
             results['Xranked'] = result['Xranked']
             results['persistence'] = result['persistence']
-            results['peak'] = result['peak']
-            results['valley'] = result['valley']
+            # results['peak'] = result['peak'] # These values are incorrect when using 2d
+            # results['valley'] = result['valley'] # These values are incorrect when using 2d
             results['groups0'] = result['groups0']
         if self.method=='mask':
             results['Xdetect'] = result
@@ -747,7 +750,7 @@ class findpeaks():
         ax2.grid(False)
 
         # Masking
-        ax3.imshow(Xdetect, cmap, interpolation="nearest")
+        ax3.imshow(Xdetect, 'gray_r', interpolation="nearest")
         ax3.set_title(self.method + ' method')
         ax3.grid(False)
         
@@ -910,12 +913,12 @@ class findpeaks():
                     y, x = p_birth
                     Xdetect[y, x] = i + 1
                     ax1.plot([x], [y], '.', c='b')
-                    ax1.text(x, y + 0.25, str(i + 1), color='b')
+                    ax1.text(x, y + 0.25, str(i), color='b')
                 elif pers > self.limit:
                     y, x = p_birth
                     Xdetect[y, x] = i + 1
                     ax1.plot([x], [y], '.', c='b')
-                    ax1.text(x, y + 0.25, str(i + 1), color='b')
+                    ax1.text(x, y + 0.25, str(i), color='b')
 
             ax1.set_xlim((0, self.results['Xproc'].shape[1]))
             ax1.set_ylim((0, self.results['Xproc'].shape[0]))
