@@ -289,14 +289,16 @@ def topology(X, limit=None, verbose=3):
             detected peaks with respect the input image. Elements are the scores.
         Xranked : array-like (same shape as input data)
             detected peaks with respect the input image. Elements are the ranked peaks (1=best).
-        max_peaks : array-like
+        peak : array-like
             Detected peaks
-        min_peaks : array-like
-            Detected vallyes
+        valley : array-like
+            Detected valley
+        groups0 : array-like
+            Unstructured results
         persistence : DataFrame()
             * x, y    : coordinates
-            * birth   : Birth level
-            * death   : Death level
+            * birth   : Birth level, tuple(coordinate, rgb value)
+            * death   : Death level, tuple(coordinate, rgb value)
             * score   : persistence scores
 
     References
@@ -304,7 +306,7 @@ def topology(X, limit=None, verbose=3):
     * https://www.sthu.org/code/codesnippets/imagepers.html
     * H. Edelsbrunner and J. Harer, Computational Topology. An Introduction, 2010, ISBN 0-8218-4925-5.
     * Initial implementation: Stefan Huber <shuber@sthu.org>
-    * Editted by: Erdogan Taskesen <erdogant@gmail.com>
+    * Editted by: Erdogan Taskesen <erdogant@gmail.com>, 2020
 
     """
     if verbose>=3: print('[findpeaks] >Detect peaks using topology method with limit at %s.' %(limit))
@@ -358,7 +360,7 @@ def topology(X, limit=None, verbose=3):
     # Extract the min peaks and sort
     min_peaks = np.array(list(map(lambda x: [(x[3][0] if x[3] is not None else 0), x[2]], groups0)))
     idxsort = np.argsort(min_peaks[:, 0])
-    min_peaks = min_peaks[idxsort, :].tolist()
+    min_peaks = min_peaks[idxsort, :]
 
     # Build the output results in the same manner as the input image
     Xdetect = np.zeros_like(X).astype(float)
@@ -376,8 +378,8 @@ def topology(X, limit=None, verbose=3):
 
     # Store in dataframe
     df_persistence = pd.DataFrame()
-    df_persistence['x'] = np.array(list(map(lambda x: x[0][0], groups0)))
-    df_persistence['y'] = np.array(list(map(lambda x: x[1], groups0)))
+    df_persistence['x'] = np.array(list(map(lambda x: x[0][1], groups0)))
+    df_persistence['y'] = np.array(list(map(lambda x: x[0][0], groups0)))
     df_persistence['birth_level'] = np.array(list(map(lambda x: x[1], groups0)))
     df_persistence['death_level'] = np.array(list(map(lambda x: x[1] - x[2], groups0)))
     df_persistence['score'] = np.array(list(map(lambda x: x[2], groups0)))
@@ -427,8 +429,8 @@ def _post_processing(X, Xraw, min_peaks, max_peaks, interpolate, lookahead, labx
     results['labx'] = np.zeros((len(Xraw))) * np.nan
     results['min_peaks'] = None
     results['max_peaks'] = None
-
-    if len(min_peaks)>0 and len(max_peaks)>0:
+    
+    if len(min_peaks)>0 and len(max_peaks)>0 and (max_peaks[0][0] is not None):
 
         idx_peaks, _ = zip(*max_peaks)
         idx_peaks = np.array(list(idx_peaks)).astype(int)
